import { DocumentTextIcon, MenuIcon, XIcon } from '@heroicons/react/outline';

import { useMenu } from './MenuContext';
import ThemeButton from './ThemeButton';

export default function Header() {
  const { isOpen, setIsOpen } = useMenu();

  return (
    <header className="sticky top-0 z-10 border-b border-slate-200/60 bg-slate-50 dark:border-slate-300/10 dark:bg-slate-900">
      <nav className="max-w-8xl mx-auto px-4 sm:px-6 lg:px-8" aria-label="Top">
        <div className="flex w-full items-center justify-between py-4">
          <div className="flex">
            <div className="mr-4 flex lg:hidden">
              {isOpen ? (
                <button type="button" onClick={() => setIsOpen(false)} aria-label="Close navigation">
                  <XIcon className="h-6 w-6" />
                </button>
              ) : (
                <button type="button" onClick={() => setIsOpen(true)} aria-label="Open navigation">
                  <MenuIcon className="h-6 w-6" />
                </button>
              )}
            </div>

            <a href="/" className="flex items-center">
              <DocumentTextIcon className="h-6 w-auto text-indigo-600 dark:text-indigo-500" />
              <h1 className="ml-2 font-semibold">{process.env.SITE_NAME}</h1>
            </a>
          </div>

          <div className="flex items-center space-x-4">
            <div>
              <ThemeButton className="h-6 w-auto" />
            </div>
            <div>
              <GitHubButton className="h-6 w-auto" />
            </div>
          </div>
        </div>
      </nav>
    </header>
  );
}

export function GitHubButton(props) {
  return (
    <div {...props}>
      <a className="flex items-center" href={process.env.GITHUB_URL} target="_blank">
        <svg fill="currentColor" viewBox="0 0 24 24" {...props}>
          <path d="M12 2C6.477 2 2 6.484 2 12.017c0 4.425 2.865 8.18 6.839 9.504.5.092.682-.217.682-.483 0-.237-.008-.868-.013-1.703-2.782.605-3.369-1.343-3.369-1.343-.454-1.158-1.11-1.466-1.11-1.466-.908-.62.069-.608.069-.608 1.003.07 1.531 1.032 1.531 1.032.892 1.53 2.341 1.088 2.91.832.092-.647.35-1.088.636-1.338-2.22-.253-4.555-1.113-4.555-4.951 0-1.093.39-1.988 1.029-2.688-.103-.253-.446-1.272.098-2.65 0 0 .84-.27 2.75 1.026A9.564 9.564 0 0112 6.844c.85.004 1.705.115 2.504.337 1.909-1.296 2.747-1.027 2.747-1.027.546 1.379.202 2.398.1 2.651.64.7 1.028 1.595 1.028 2.688 0 3.848-2.339 4.695-4.566 4.943.359.309.678.92.678 1.855 0 1.338-.012 2.419-.012 2.747 0 .268.18.58.688.482A10.019 10.019 0 0022 12.017C22 6.484 17.522 2 12 2z" />
        </svg>
      </a>
    </div>
  );
}
